@@ -4,7 +4,7 @@
 [![NuGet version](https://badge.fury.io/nu/cdkgithub.svg)](https://badge.fury.io/nu/cdkgithub)
 [![Maven Central](https://maven-badges.herokuapp.com/maven-central/io.github.wtfjoke/cdk-github/badge.svg)](https://maven-badges.herokuapp.com/maven-central/io.github.wtfjoke/cdk-github/)
 [![release](https://github.com/wtfjoke/cdk-github/actions/workflows/release.yml/badge.svg)](https://github.com/wtfjoke/cdk-github/actions/workflows/release.yml)
-![cdk-constructs: Experimental](https://img.shields.io/badge/cdk--constructs-experimental-important.svg?style=for-the-badge)
+![cdk-constructs: Experimental](https://img.shields.io/badge/cdk--constructs-experimental-important.svg?style=for-the-badge) [![View on Construct Hub](https://constructs.dev/badge?package=cdk-github)](https://constructs.dev/packages/cdk-github)
 
 # CDK-GitHub
 
@@ -189,6 +189,7 @@ class ActionEnvironmentSecret(
         repository_secret_name: builtins.str,
         source_secret: aws_cdk.aws_secretsmanager.ISecret,
         repository_owner: typing.Optional[builtins.str] = None,
+        source_secret_json_field: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param scope: -
@@ -199,6 +200,7 @@ class ActionEnvironmentSecret(
         :param repository_secret_name: (experimental) The GitHub secret name to be stored.
         :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
         :param repository_owner: (experimental) The GitHub repository owner. Default: - user account which owns the token
+        :param source_secret_json_field: (experimental) The key of a JSON field to retrieve in sourceSecret. This can only be used if the secret stores a JSON object. Default: - returns all the content stored in the Secrets Manager secret.
 
         :stability: experimental
         '''
@@ -209,6 +211,7 @@ class ActionEnvironmentSecret(
             repository_secret_name=repository_secret_name,
             source_secret=source_secret,
             repository_owner=repository_owner,
+            source_secret_json_field=source_secret_json_field,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -224,6 +227,7 @@ class ActionEnvironmentSecret(
         "repository_secret_name": "repositorySecretName",
         "source_secret": "sourceSecret",
         "repository_owner": "repositoryOwner",
+        "source_secret_json_field": "sourceSecretJsonField",
     },
 )
 class ActionEnvironmentSecretProps:
@@ -236,6 +240,7 @@ class ActionEnvironmentSecretProps:
         repository_secret_name: builtins.str,
         source_secret: aws_cdk.aws_secretsmanager.ISecret,
         repository_owner: typing.Optional[builtins.str] = None,
+        source_secret_json_field: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param environment: (experimental) The GithHub environment name which the secret should be stored in.
@@ -244,6 +249,7 @@ class ActionEnvironmentSecretProps:
         :param repository_secret_name: (experimental) The GitHub secret name to be stored.
         :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
         :param repository_owner: (experimental) The GitHub repository owner. Default: - user account which owns the token
+        :param source_secret_json_field: (experimental) The key of a JSON field to retrieve in sourceSecret. This can only be used if the secret stores a JSON object. Default: - returns all the content stored in the Secrets Manager secret.
 
         :stability: experimental
         '''
@@ -256,6 +262,8 @@ class ActionEnvironmentSecretProps:
         }
         if repository_owner is not None:
             self._values["repository_owner"] = repository_owner
+        if source_secret_json_field is not None:
+            self._values["source_secret_json_field"] = source_secret_json_field
 
     @builtins.property
     def environment(self) -> builtins.str:
@@ -318,6 +326,19 @@ class ActionEnvironmentSecretProps:
         result = self._values.get("repository_owner")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def source_secret_json_field(self) -> typing.Optional[builtins.str]:
+        '''(experimental) The key of a JSON field to retrieve in sourceSecret.
+
+        This can only be used if the secret stores a JSON object.
+
+        :default: - returns all the content stored in the Secrets Manager secret.
+
+        :stability: experimental
+        '''
+        result = self._values.get("source_secret_json_field")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -349,6 +370,7 @@ class ActionSecret(
         repository_secret_name: builtins.str,
         source_secret: aws_cdk.aws_secretsmanager.ISecret,
         repository_owner: typing.Optional[builtins.str] = None,
+        source_secret_json_field: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param scope: -
@@ -358,6 +380,7 @@ class ActionSecret(
         :param repository_secret_name: (experimental) The GitHub secret name to be stored.
         :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
         :param repository_owner: (experimental) The GitHub repository owner. Default: - user account which owns the token
+        :param source_secret_json_field: (experimental) The key of a JSON field to retrieve in sourceSecret. This can only be used if the secret stores a JSON object. Default: - returns all the content stored in the Secrets Manager secret.
 
         :stability: experimental
         '''
@@ -367,6 +390,7 @@ class ActionSecret(
             repository_secret_name=repository_secret_name,
             source_secret=source_secret,
             repository_owner=repository_owner,
+            source_secret_json_field=source_secret_json_field,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -381,6 +405,7 @@ class ActionSecret(
         "repository_secret_name": "repositorySecretName",
         "source_secret": "sourceSecret",
         "repository_owner": "repositoryOwner",
+        "source_secret_json_field": "sourceSecretJsonField",
     },
 )
 class ActionSecretProps:
@@ -392,6 +417,7 @@ class ActionSecretProps:
         repository_secret_name: builtins.str,
         source_secret: aws_cdk.aws_secretsmanager.ISecret,
         repository_owner: typing.Optional[builtins.str] = None,
+        source_secret_json_field: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
         :param github_token_secret: (experimental) The AWS secret in which the OAuth GitHub (personal) access token is stored.
@@ -399,6 +425,7 @@ class ActionSecretProps:
         :param repository_secret_name: (experimental) The GitHub secret name to be stored.
         :param source_secret: (experimental) This AWS secret value will be stored in GitHub as a secret (under the name of repositorySecretName).
         :param repository_owner: (experimental) The GitHub repository owner. Default: - user account which owns the token
+        :param source_secret_json_field: (experimental) The key of a JSON field to retrieve in sourceSecret. This can only be used if the secret stores a JSON object. Default: - returns all the content stored in the Secrets Manager secret.
 
         :stability: experimental
         '''
@@ -410,6 +437,8 @@ class ActionSecretProps:
         }
         if repository_owner is not None:
             self._values["repository_owner"] = repository_owner
+        if source_secret_json_field is not None:
+            self._values["source_secret_json_field"] = source_secret_json_field
 
     @builtins.property
     def github_token_secret(self) -> aws_cdk.aws_secretsmanager.ISecret:
@@ -462,6 +491,19 @@ class ActionSecretProps:
         result = self._values.get("repository_owner")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def source_secret_json_field(self) -> typing.Optional[builtins.str]:
+        '''(experimental) The key of a JSON field to retrieve in sourceSecret.
+
+        This can only be used if the secret stores a JSON object.
+
+        :default: - returns all the content stored in the Secrets Manager secret.
+
+        :stability: experimental
+        '''
+        result = self._values.get("source_secret_json_field")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
